@@ -120,7 +120,7 @@ gpm_applet_inhibit (GpmInhibitApplet *applet,
 		g_error_free (error);
 		*cookie = 0;
 	}
-	if (ret == FALSE) {
+	if (!ret) {
 		/* abort as the DBUS method failed */
 		g_warning ("Inhibit failed!");
 	}
@@ -148,7 +148,7 @@ gpm_applet_uninhibit (GpmInhibitApplet *applet,
 		g_debug ("ERROR: %s", error->message);
 		g_error_free (error);
 	}
-	if (ret == FALSE) {
+	if (!ret) {
 		/* abort as the DBUS method failed */
 		g_warning ("UnInhibit failed!");
 	}
@@ -178,7 +178,7 @@ gpm_applet_has_inhibit (GpmInhibitApplet *applet,
 		g_debug ("ERROR: %s", error->message);
 		g_error_free (error);
 	}
-	if (ret == FALSE) {
+	if (!ret) {
 		/* abort as the DBUS method failed */
 		g_warning ("HasInhibit failed!");
 	}
@@ -244,12 +244,20 @@ gpm_applet_check_size (GpmInhibitApplet *applet)
 			gpm_applet_get_icon (applet);
 			gtk_widget_set_size_request (GTK_WIDGET(applet), applet->size, applet->icon_height + 2);
 		}
+		/* Adjusting incase the icon size has changed */
+		if (GTK_WIDGET(applet)->allocation.height < applet->icon_height + 2) {
+			gtk_widget_set_size_request (GTK_WIDGET(applet), applet->size, applet->icon_height + 2);
+		}
 	} else {
 		if (applet->size != GTK_WIDGET(applet)->allocation.height) {
 			applet->size = GTK_WIDGET(applet)->allocation.height;
 			gpm_applet_get_icon (applet);
 			gtk_widget_set_size_request (GTK_WIDGET(applet), applet->icon_width + 2, applet->size);
 		}
+		/* Adjusting incase the icon size has changed */
+		if (GTK_WIDGET(applet)->allocation.width < applet->icon_width + 2) {
+			gtk_widget_set_size_request (GTK_WIDGET(applet), applet->icon_width + 2, applet->size);
+		}
 	}
 }
 
@@ -271,6 +279,9 @@ gpm_applet_draw_cb (GpmInhibitApplet *applet)
 		return FALSE;
 	}
 
+	/* Clear the window so we can draw on it later */
+	gdk_window_clear(GTK_WIDGET(applet)->window);
+
 	/* retrieve applet size */
 	gpm_applet_get_icon (applet);
 	gpm_applet_check_size (applet);
@@ -333,14 +344,14 @@ gpm_applet_change_background_cb (GpmInhibitApplet *applet,
 static void
 gpm_applet_update_tooltip (GpmInhibitApplet *applet)
 {
-	static gchar buf[101];
+	const gchar *buf;
 	if (applet->proxy == NULL) {
-		snprintf (buf, 100, _("Cannot connect to gnome-power-manager"));
+		buf = _("Cannot connect to gnome-power-manager");
 	} else {
 		if (applet->cookie > 0) {
-			snprintf (buf, 100, _("Automatic sleep inhibited"));
+			buf = _("Automatic sleep inhibited");
 		} else {
-			snprintf (buf, 100, _("Automatic sleep enabled"));
+			buf = _("Automatic sleep enabled");
 		}
 	}
 	gtk_widget_set_tooltip_text (GTK_WIDGET(applet), buf);
@@ -373,6 +384,7 @@ gpm_applet_click_cb (GpmInhibitApplet *applet, GdkEventButton *event)
 	}
 	/* update icon */
 	gpm_applet_get_icon (applet);
+	gpm_applet_check_size (applet);
 	gpm_applet_update_tooltip (applet);
 	gpm_applet_draw_cb (applet);
 
@@ -465,7 +477,7 @@ gpm_applet_help_cb (BonoboUIComponent *uic, gpointer data, const gchar *verbname
 						GTK_DIALOG_DESTROY_WITH_PARENT,
 						GTK_MESSAGE_ERROR,
 						GTK_BUTTONS_CLOSE,
-						error->message);
+						"%s", error->message);
 		gtk_dialog_run (GTK_DIALOG (dialog));
 		gtk_widget_destroy (dialog);
 		g_error_free (error);
