@@ -48,8 +48,7 @@
 #include "gpm-conf.h"
 #include "gpm-control.h"
 #include "gpm-common.h"
-#include "gpm-cpufreq.h"
-#include "gpm-debug.h"
+#include "egg-debug.h"
 #include "gpm-dpms.h"
 #include "gpm-idle.h"
 #include "gpm-info.h"
@@ -100,7 +99,6 @@ struct GpmManagerPrivate
 	/* interactive services */
 	GpmBacklight		*backlight;
 	GpmSrvBrightnessKbd	*srv_brightness_kbd;
-	GpmCpufreq	 	*cpufreq;
 	GpmSrvScreensaver 	*srv_screensaver;
 };
 
@@ -171,33 +169,33 @@ gpm_manager_is_inhibit_valid (GpmManager *manager,
 			      const char *action)
 {
 	gboolean has_inhibit;
-	gchar *title;
+	gchar *title = NULL;
 
 	/* We have to decide on whether this is a idle action or a user keypress */
 	gpm_inhibit_has_inhibit (manager->priv->inhibit, &has_inhibit, NULL);
 
-	if (has_inhibit == TRUE) {
+	if (has_inhibit) {
 		GString *message = g_string_new ("");
 		const char *msg;
 
 		/*Compose message for each possible action*/
 		if (strcmp (action, "suspend") == 0) {
-				title = g_strdup_printf (_("Request to suspend")); 
+				title = g_strdup (_("Request to suspend")); 
 
 		} else if (strcmp (action, "hibernate") == 0) {
-				title = g_strdup_printf (_("Request to hibernate")); 
+				title = g_strdup (_("Request to hibernate")); 
 
 		} else if (strcmp (action, "policy action") == 0) {
-				title = g_strdup_printf (_("Request to do policy action")); 
+				title = g_strdup (_("Request to do policy action")); 
 
 		} else if (strcmp (action, "reboot") == 0) {
-				title = g_strdup_printf (_("Request to reboot")); 
+				title = g_strdup (_("Request to reboot")); 
 
 		} else if (strcmp (action, "shutdown") == 0) {
-				title = g_strdup_printf (_("Request to shutdown")); 
+				title = g_strdup (_("Request to shutdown")); 
 
 		} else if (strcmp (action, "timeout action") == 0) {
-				title = g_strdup_printf (_("Request to do timeout action"));
+				title = g_strdup (_("Request to do timeout action"));
 		}
 		
 		gpm_inhibit_get_message (manager->priv->inhibit, message, action);
@@ -235,7 +233,7 @@ gpm_manager_sync_policy_sleep (GpmManager *manager)
 
 	on_ac = gpm_ac_adapter_is_present (manager->priv->ac_adapter);
 
-	if (on_ac == TRUE) {
+	if (on_ac) {
 		gpm_conf_get_uint (manager->priv->conf, GPM_CONF_TIMEOUT_SLEEP_COMPUTER_AC, &sleep_computer);
 		gpm_conf_get_uint (manager->priv->conf, GPM_CONF_TIMEOUT_SLEEP_DISPLAY_AC, &sleep_display);
 		gpm_conf_get_bool (manager->priv->conf, GPM_CONF_LOWPOWER_AC, &power_save);
@@ -272,13 +270,13 @@ gpm_manager_blank_screen (GpmManager *manager,
 
 	do_lock = gpm_control_get_lock_policy (manager->priv->control,
 					       GPM_CONF_LOCK_ON_BLANK_SCREEN);
-	if (do_lock == TRUE) {
+	if (do_lock) {
 		if (!gpm_screensaver_lock (manager->priv->screensaver))
-			gpm_debug ("Could not lock screen via gnome-screensaver");
+			egg_debug ("Could not lock screen via gnome-screensaver");
 	}
 	gpm_dpms_set_mode_enum (manager->priv->dpms, GPM_DPMS_MODE_OFF, &error);
 	if (error) {
-		gpm_debug ("Unable to set DPMS mode: %s", error->message);
+		egg_debug ("Unable to set DPMS mode: %s", error->message);
 		g_error_free (error);
 		ret = FALSE;
 	}
@@ -304,13 +302,13 @@ gpm_manager_unblank_screen (GpmManager *manager,
 	error = NULL;
 	gpm_dpms_set_mode_enum (manager->priv->dpms, GPM_DPMS_MODE_ON, &error);
 	if (error) {
-		gpm_debug ("Unable to set DPMS mode: %s", error->message);
+		egg_debug ("Unable to set DPMS mode: %s", error->message);
 		g_error_free (error);
 		ret = FALSE;
 	}
 
 	do_lock = gpm_control_get_lock_policy (manager->priv->control, GPM_CONF_LOCK_ON_BLANK_SCREEN);
-	if (do_lock == TRUE) {
+	if (do_lock) {
 		gpm_screensaver_poke (manager->priv->screensaver);
 	}
 	return ret;
@@ -429,23 +427,12 @@ manager_policy_do (GpmManager  *manager,
 {
 	gchar *action = NULL;
 
-	/* error msg timeout not valid */
-	if (gpm_control_is_policy_timout_valid (manager->priv->control) == FALSE) {
-		gpm_notify_display (manager->priv->notify,
-				    _("Action forbidden"),
-				    _("Policy timeout is not valid. Please wait a few seconds and try again."),
-				    GPM_NOTIFY_TIMEOUT_SHORT,
-				    GPM_STOCK_APP_ICON,
-				    GPM_NOTIFY_URGENCY_NORMAL);
-		return FALSE;
-	}
-
 	/* are we inhibited? */
 	if (gpm_manager_is_inhibit_valid (manager, FALSE, "policy action") == FALSE) {
 		return FALSE;
 	}
 
-	gpm_debug ("policy: %s", policy);
+	egg_debug ("policy: %s", policy);
 	gpm_conf_get_string (manager->priv->conf, policy, &action);
 
 	if (action == NULL) {
@@ -477,7 +464,7 @@ manager_policy_do (GpmManager  *manager,
 					   GNOME_SAVE_GLOBAL,
 					   TRUE, GNOME_INTERACT_ANY, FALSE, TRUE);
 	} else {
-		gpm_warning ("unknown action %s", action);
+		egg_warning ("unknown action %s", action);
 	}
 
 	g_free (action);
@@ -707,7 +694,7 @@ gpm_manager_get_on_battery (GpmManager *manager,
 	g_return_val_if_fail (manager != NULL, FALSE);
 	g_return_val_if_fail (GPM_IS_MANAGER (manager), FALSE);
 	on_ac = gpm_ac_adapter_is_present (manager->priv->ac_adapter);
-	if (on_ac == TRUE) {
+	if (on_ac) {
 		*on_battery = FALSE;
 	} else {
 		*on_battery = TRUE;
@@ -749,31 +736,31 @@ idle_do_sleep (GpmManager *manager)
 	/* find if we are on AC power */
 	on_ac = gpm_ac_adapter_is_present (manager->priv->ac_adapter);
 
-	if (on_ac == TRUE) {
+	if (on_ac) {
 		gpm_conf_get_string (manager->priv->conf, GPM_CONF_ACTIONS_SLEEP_TYPE_AC, &action);
 	} else {
 		gpm_conf_get_string (manager->priv->conf, GPM_CONF_ACTIONS_SLEEP_TYPE_BATT, &action);
 	}
 
 	if (action == NULL) {
-		gpm_warning ("action NULL, gconf error");
+		egg_warning ("action NULL, gconf error");
 		return;
 	}
 
 	if (strcmp (action, ACTION_NOTHING) == 0) {
-		gpm_debug ("doing nothing as system idle action");
+		egg_debug ("doing nothing as system idle action");
 
 	} else if (strcmp (action, ACTION_SUSPEND) == 0) {
 		gpm_info_explain_reason (manager->priv->info, GPM_EVENT_SUSPEND,
 					_("Suspending computer."), _("System idle."));
 		ret = gpm_control_suspend (manager->priv->control, &error);
-		if (ret == FALSE) {
-			gpm_warning ("cannot suspend (error: %s), so trying hibernate", error->message);
+		if (!ret) {
+			egg_warning ("cannot suspend (error: %s), so trying hibernate", error->message);
 			g_error_free (error);
 			error = NULL;
 			ret = gpm_control_hibernate (manager->priv->control, &error);
-			if (ret == FALSE) {
-				gpm_warning ("cannot suspend or hibernate: %s", error->message);
+			if (!ret) {
+				egg_warning ("cannot suspend or hibernate: %s", error->message);
 				g_error_free (error);
 			}
 		}
@@ -782,13 +769,13 @@ idle_do_sleep (GpmManager *manager)
 		gpm_info_explain_reason (manager->priv->info, GPM_EVENT_HIBERNATE,
 					_("Hibernating computer."), _("System idle."));
 		ret = gpm_control_hibernate (manager->priv->control, &error);
-		if (ret == FALSE) {
-			gpm_warning ("cannot hibernate (error: %s), so trying suspend", error->message);
+		if (!ret) {
+			egg_warning ("cannot hibernate (error: %s), so trying suspend", error->message);
 			g_error_free (error);
 			error = NULL;
 			ret = gpm_control_suspend (manager->priv->control, &error);
-			if (ret == FALSE) {
-				gpm_warning ("cannot suspend or hibernate: %s", error->message);
+			if (!ret) {
+				egg_warning ("cannot suspend or hibernate: %s", error->message);
 				g_error_free (error);
 			}
 		}
@@ -817,25 +804,22 @@ idle_changed_cb (GpmIdle    *idle,
 	 * the screen when the user moves the mouse on systems that do not
 	 * support hardware blanking.
 	 * Details are here: https://launchpad.net/malone/bugs/22522 */
-	if (gpm_button_is_lid_closed (manager->priv->button) == TRUE) {
-		gpm_debug ("lid is closed, so we are ignoring idle state changes");
+	if (gpm_button_is_lid_closed (manager->priv->button)) {
+		egg_debug ("lid is closed, so we are ignoring idle state changes");
 		return;
 	}
 
 	if (mode == GPM_IDLE_MODE_NORMAL) {
 
-		gpm_debug ("Idle state changed: NORMAL");
+		egg_debug ("Idle state changed: NORMAL");
 
 	} else if (mode == GPM_IDLE_MODE_SESSION) {
 
-		gpm_debug ("Idle state changed: SESSION");
+		egg_debug ("Idle state changed: SESSION");
 
 	} else if (mode == GPM_IDLE_MODE_SYSTEM) {
-		gpm_debug ("Idle state changed: SYSTEM");
+		egg_debug ("Idle state changed: SYSTEM");
 
-		if (gpm_control_is_policy_timout_valid (manager->priv->control) == FALSE) {
-			return;
-		}
 		if (gpm_manager_is_inhibit_valid (manager, FALSE, "timeout action") == FALSE) {
 			return;
 		}
@@ -926,8 +910,8 @@ lid_button_pressed (GpmManager *manager,
 		return;
 	}
 
-	if (on_ac == TRUE) {
-		gpm_debug ("Performing AC policy");
+	if (on_ac) {
+		egg_debug ("Performing AC policy");
 		manager_policy_do (manager, GPM_CONF_BUTTON_LID_AC,
 				   _("The lid has been closed on ac power."));
 		return;
@@ -940,7 +924,7 @@ lid_button_pressed (GpmManager *manager,
 	gpm_inhibit_has_inhibit (manager->priv->inhibit, &has_inhibit, NULL);
 
 	/* do not do lid close action if suspend (or hibernate) */
-	if (has_inhibit == TRUE) {
+	if (has_inhibit) {
 		/* get the policy action for battery */
 		gpm_conf_get_string (manager->priv->conf, GPM_CONF_BUTTON_LID_BATT, &action);
 
@@ -953,11 +937,11 @@ lid_button_pressed (GpmManager *manager,
 	}
 
 	if (do_policy == FALSE) {
-		gpm_debug ("Not doing lid policy action as inhibited as set to sleep");
+		egg_debug ("Not doing lid policy action as inhibited as set to sleep");
 		return;
 	}
 
-	gpm_debug ("Performing battery policy");
+	egg_debug ("Performing battery policy");
 	manager_policy_do (manager, GPM_CONF_BUTTON_LID_BATT,
 			   _("The lid has been closed on battery power."));
 }
@@ -974,7 +958,7 @@ button_pressed_cb (GpmButton   *button,
 		   const gchar *type,
 		   GpmManager  *manager)
 {
-	gpm_debug ("Button press event type=%s", type);
+	egg_debug ("Button press event type=%s", type);
 
 	if (strcmp (type, GPM_BUTTON_POWER) == 0) {
 		power_button_pressed (manager);
@@ -1015,19 +999,19 @@ ac_adapter_changed_cb (GpmAcAdapter *ac_adapter,
 	gboolean event_when_closed;
 	gboolean power_save;
 
-	gpm_debug ("Setting on-ac: %d", on_ac);
+	egg_debug ("Setting on-ac: %d", on_ac);
 
 	gpm_manager_sync_policy_sleep (manager);
 
-	gpm_debug ("emitting on-ac-changed : %i", on_ac);
-	if (on_ac == TRUE) {
+	egg_debug ("emitting on-ac-changed : %i", on_ac);
+	if (on_ac) {
 		g_signal_emit (manager, signals [ON_BATTERY_CHANGED], 0, FALSE);
 	} else {
 		g_signal_emit (manager, signals [ON_BATTERY_CHANGED], 0, TRUE);
 	}
 
 	on_ac = gpm_ac_adapter_is_present (manager->priv->ac_adapter);
-	if (on_ac == TRUE) {
+	if (on_ac) {
 		gpm_conf_get_bool (manager->priv->conf, GPM_CONF_LOWPOWER_AC, &power_save);
 	} else {
 		gpm_conf_get_bool (manager->priv->conf, GPM_CONF_LOWPOWER_BATT, &power_save);
@@ -1044,17 +1028,13 @@ ac_adapter_changed_cb (GpmAcAdapter *ac_adapter,
 	/* We keep track of the lid state so we can do the
 	   lid close on battery action if the ac_adapter is removed when the laptop
 	   is closed. Fixes #331655 */
-	if (event_when_closed == TRUE &&
+	if (event_when_closed &&
 	    on_ac == FALSE &&
 	    gpm_button_is_lid_closed (manager->priv->button)) {
 		manager_policy_do (manager, GPM_CONF_BUTTON_LID_BATT,
 				   _("The lid has been closed, and the ac adapter "
 				     "removed (and gconf is okay)."));
 	}
-
-	/* Don't do any events for a few seconds after we remove the
-	 * ac_adapter. See #348201 for details */
-	gpm_control_reset_event_time (manager->priv->control);
 }
 
 /**
@@ -1194,10 +1174,10 @@ gpm_manager_check_sleep_errors (GpmManager *manager)
 	hal_gpower_has_suspend_error (manager->priv->hal_power, &suspend_error);
 	hal_gpower_has_hibernate_error (manager->priv->hal_power, &hibernate_error);
 
-	if (suspend_error == TRUE) {
+	if (suspend_error) {
 		gpm_notify_sleep_failed (manager->priv->notify, FALSE);
 	}
-	if (hibernate_error == TRUE) {
+	if (hibernate_error) {
 		gpm_notify_sleep_failed (manager->priv->notify, TRUE);
 	}
 }
@@ -1220,14 +1200,14 @@ screensaver_auth_request_cb (GpmScreensaver *screensaver,
 	if (auth_begin == FALSE) {
 		error = NULL;
 		ret = hal_gpower_clear_suspend_error (manager->priv->hal_power, &error);
-		if (ret == FALSE) {
-			gpm_debug ("Failed to clear suspend error; %s", error->message);
+		if (!ret) {
+			egg_debug ("Failed to clear suspend error; %s", error->message);
 			g_error_free (error);
 		}
 		error = NULL;
 		ret = hal_gpower_clear_hibernate_error (manager->priv->hal_power, &error);
-		if (ret == FALSE) {
-			gpm_debug ("Failed to clear hibernate error; %s", error->message);
+		if (!ret) {
+			egg_debug ("Failed to clear hibernate error; %s", error->message);
 			g_error_free (error);
 		}
 	}
@@ -1360,12 +1340,12 @@ control_sleep_failure_cb (GpmControl      *control,
 	gpm_conf_get_bool (manager->priv->conf, GPM_CONF_NOTIFY_SLEEP_FAILED, &show_sleep_failed);
 
 	/* only emit if in GConf */
-	if (show_sleep_failed == TRUE) {
+	if (show_sleep_failed) {
 		if (action == GPM_CONTROL_ACTION_SUSPEND) {
-			gpm_syslog ("suspend failed");
+			egg_debug ("suspend failed");
 			gpm_notify_sleep_failed (manager->priv->notify, FALSE);
 		} else {
-			gpm_syslog ("hibernate failed");
+			egg_debug ("hibernate failed");
 			gpm_notify_sleep_failed (manager->priv->notify, TRUE);
 		}
 	}
@@ -1388,25 +1368,25 @@ gpm_engine_charge_low_cb (GpmEngine      *engine,
 	if (kind == GPM_CELL_UNIT_KIND_PRIMARY) {
 		title = _("Laptop battery low");
 		remaining_text = gpm_get_timestring (unit->time_discharge);
-		message = g_strdup_printf (_("You have approximately <b>%s</b> of remaining battery life (%d%%)"),
+		message = g_strdup_printf (_("You have approximately <b>%s</b> of remaining battery life (%.1f%%)"),
 					   remaining_text, unit->percentage);
 	} else if (kind == GPM_CELL_UNIT_KIND_UPS) {
 		title = _("UPS low");
 		remaining_text = gpm_get_timestring (unit->time_discharge);
-		message = g_strdup_printf (_("You have approximately <b>%s</b> of remaining UPS backup power (%d%%)"),
+		message = g_strdup_printf (_("You have approximately <b>%s</b> of remaining UPS backup power (%.1f%%)"),
 					   remaining_text, unit->percentage);
 	} else if (kind == GPM_CELL_UNIT_KIND_MOUSE) {
 		title = _("Mouse battery low");
-		message = g_strdup_printf (_("The wireless mouse attached to this computer is low in power (%d%%)"), unit->percentage);
+		message = g_strdup_printf (_("The wireless mouse attached to this computer is low in power (%.1f%%)"), unit->percentage);
 	} else if (kind == GPM_CELL_UNIT_KIND_KEYBOARD) {
 		title = _("Keyboard battery low");
-		message = g_strdup_printf (_("The wireless keyboard attached to this computer is low in power (%d%%)"), unit->percentage);
+		message = g_strdup_printf (_("The wireless keyboard attached to this computer is low in power (%.1f%%)"), unit->percentage);
 	} else if (kind == GPM_CELL_UNIT_KIND_PDA) {
 		title = _("PDA battery low");
-		message = g_strdup_printf (_("The PDA attached to this computer is low in power (%d%%)"), unit->percentage);
+		message = g_strdup_printf (_("The PDA attached to this computer is low in power (%.1f%%)"), unit->percentage);
 	} else if (kind == GPM_CELL_UNIT_KIND_PHONE) {
 		title = _("Cell phone battery low");
-		message = g_strdup_printf (_("The cell phone attached to this computer is low in power (%d%%)"), unit->percentage);
+		message = g_strdup_printf (_("The cell phone attached to this computer is low in power (%.1f%%)"), unit->percentage);
 	}
 
 	/* get correct icon */
@@ -1463,13 +1443,13 @@ gpm_engine_charge_critical_cb (GpmEngine      *engine,
 		/* we have to do different warnings depending on the policy */
 		gpm_conf_get_string (manager->priv->conf, GPM_CONF_ACTIONS_CRITICAL_BATT, &action);
 		if (action == NULL) {
-			gpm_warning ("schema invalid!");
+			egg_warning ("schema invalid!");
 			action = g_strdup (ACTION_NOTHING);
 		}
 
 		/* use different text for different actions */
 		if (strcmp (action, ACTION_NOTHING) == 0) {
-			action_text = g_strdup_printf (_("Plug in your AC adapter to avoid losing data."));
+			action_text = g_strdup (_("Plug in your AC adapter to avoid losing data."));
 
 		} else if (strcmp (action, ACTION_SUSPEND) == 0) {
 			action_text = g_strdup_printf (_("This computer will suspend in %s if the AC is not connected."), time_text);
@@ -1481,7 +1461,7 @@ gpm_engine_charge_critical_cb (GpmEngine      *engine,
 			action_text = g_strdup_printf (_("This computer will shutdown in %s if the AC is not connected."), time_text);
 		}
 
-		message = g_strdup_printf (_("You have approximately <b>%s</b> of remaining battery life (%d%%). %s"),
+		message = g_strdup_printf (_("You have approximately <b>%s</b> of remaining battery life (%.1f%%). %s"),
 					   remaining_text, unit->percentage, action_text);
 
 		g_free (action);
@@ -1491,28 +1471,28 @@ gpm_engine_charge_critical_cb (GpmEngine      *engine,
 	} else if (kind == GPM_CELL_UNIT_KIND_UPS) {
 		title = _("UPS critically low");
 		remaining_text = gpm_get_timestring (unit->time_discharge);
-		message = g_strdup_printf (_("You have approximately <b>%s</b> of remaining UPS power (%d%%). "
+		message = g_strdup_printf (_("You have approximately <b>%s</b> of remaining UPS power (%.1f%%). "
 					     "Restore AC power to your computer to avoid losing data."),
 					   remaining_text, unit->percentage);
 		g_free (remaining_text);
 	} else if (kind == GPM_CELL_UNIT_KIND_MOUSE) {
 		title = _("Mouse battery low");
-		message = g_strdup_printf (_("The wireless mouse attached to this computer is very low in power (%d%%). "
+		message = g_strdup_printf (_("The wireless mouse attached to this computer is very low in power (%.1f%%). "
 					     "This device will soon stop functioning if not charged."),
 					   unit->percentage);
 	} else if (kind == GPM_CELL_UNIT_KIND_KEYBOARD) {
 		title = _("Keyboard battery low");
-		message = g_strdup_printf (_("The wireless keyboard attached to this computer is very low in power (%d%%). "
+		message = g_strdup_printf (_("The wireless keyboard attached to this computer is very low in power (%.1f%%). "
 					     "This device will soon stop functioning if not charged."),
 					   unit->percentage);
 	} else if (kind == GPM_CELL_UNIT_KIND_PDA) {
 		title = _("PDA battery low");
-		message = g_strdup_printf (_("The PDA attached to this computer is very low in power (%d%%). "
+		message = g_strdup_printf (_("The PDA attached to this computer is very low in power (%.1f%%). "
 					     "This device will soon stop functioning if not charged."),
 					   unit->percentage);
 	} else if (kind == GPM_CELL_UNIT_KIND_PHONE) {
 		title = _("Cell phone battery low");
-		message = g_strdup_printf (_("Your cell phone is very low in power (%d%%). "
+		message = g_strdup_printf (_("Your cell phone is very low in power (%.1f%%). "
 					     "This device will soon stop functioning if not charged."),
 					   unit->percentage);
 	}
@@ -1581,17 +1561,17 @@ gpm_engine_charge_action_cb (GpmEngine      *engine,
 
 		/* use different text for different actions */
 		if (strcmp (action, ACTION_NOTHING) == 0) {
-			message = _("The UPS is below the critical level and "
-				    "this computer will <b>power-off</b> when the "
-				    "UPS becomes completely empty.");
+			message = g_strdup (_("The UPS is below the critical level and "
+				              "this computer will <b>power-off</b> when the "
+				              "UPS becomes completely empty."));
 
 		} else if (strcmp (action, ACTION_HIBERNATE) == 0) {
-			message = _("The UPS is below the critical level and "
-				    "this computer is about to hibernate.");
+			message = g_strdup (_("The UPS is below the critical level and "
+				              "this computer is about to hibernate."));
 
 		} else if (strcmp (action, ACTION_SHUTDOWN) == 0) {
-			message = _("The UPS is below the critical level and "
-				    "this computer is about to shutdown.");
+			message = g_strdup (_("The UPS is below the critical level and "
+				              "this computer is about to shutdown."));
 		}
 
 		g_free (action);
@@ -1694,7 +1674,7 @@ gpm_manager_init (GpmManager *manager)
 
 	/* check to see if the user has installed the schema properly */
 	ret = gpm_conf_get_uint (manager->priv->conf, GPM_CONF_SCHEMA_VERSION, &version);
-	if (ret == FALSE || version != GPM_CONF_SCHEMA_ID) {
+	if (!ret || version != GPM_CONF_SCHEMA_ID) {
 		gpm_notify_display (manager->priv->notify,
 				    _("Install problem!"),
 				    _("The configuration defaults for GNOME Power Manager have not been installed correctly.\n"
@@ -1702,7 +1682,7 @@ gpm_manager_init (GpmManager *manager)
 				    GPM_NOTIFY_TIMEOUT_LONG,
 				    GTK_STOCK_DIALOG_WARNING,
 				    GPM_NOTIFY_URGENCY_NORMAL);
-		gpm_error ("no gconf schema installed!");
+		egg_error ("no gconf schema installed!");
 	}
 
 	/* we use ac_adapter so we can poke the screensaver and throttle */
@@ -1712,7 +1692,7 @@ gpm_manager_init (GpmManager *manager)
 
 	/* coldplug so we are in the correct state at startup */
 	on_ac = gpm_ac_adapter_is_present (manager->priv->ac_adapter);
-	if (on_ac == TRUE) {
+	if (on_ac) {
 		gpm_conf_get_bool (manager->priv->conf, GPM_CONF_LOWPOWER_AC, &manager->priv->low_power);
 	} else {
 		gpm_conf_get_bool (manager->priv->conf, GPM_CONF_LOWPOWER_BATT, &manager->priv->low_power);
@@ -1725,9 +1705,6 @@ gpm_manager_init (GpmManager *manager)
 	manager->priv->hal_power = hal_gpower_new ();
 	manager->priv->sound = gpm_sound_new ();
 
-	/* try and start an interactive service */
-	manager->priv->cpufreq = gpm_cpufreq_new ();
-
 	/* try and start an interactive service */
 	manager->priv->screensaver = gpm_screensaver_new ();
 	g_signal_connect (manager->priv->screensaver, "auth-request",
@@ -1757,7 +1734,7 @@ gpm_manager_init (GpmManager *manager)
 	manager->priv->dpms = gpm_dpms_new ();
 
 	/* use a class to handle the complex stuff */
-	gpm_debug ("creating new inhibit instance");
+	egg_debug ("creating new inhibit instance");
 	manager->priv->inhibit = gpm_inhibit_new ();
 	g_signal_connect (manager->priv->inhibit, "has-inhibit-changed",
 			  G_CALLBACK (has_inhibit_changed_cb), manager);
@@ -1767,12 +1744,12 @@ gpm_manager_init (GpmManager *manager)
 					     G_OBJECT (manager->priv->inhibit));
 
 	/* use the control object */
-	gpm_debug ("creating new control instance");
+	egg_debug ("creating new control instance");
 	manager->priv->control = gpm_control_new ();
 	g_signal_connect (manager->priv->control, "sleep-failure",
 			  G_CALLBACK (control_sleep_failure_cb), manager);
 
-	gpm_debug ("creating new tray icon");
+	egg_debug ("creating new tray icon");
 	manager->priv->tray_icon = gpm_tray_icon_new ();
 	g_signal_connect_object (G_OBJECT (manager->priv->tray_icon),
 				 "suspend", G_CALLBACK (gpm_manager_tray_icon_suspend),
@@ -1781,7 +1758,7 @@ gpm_manager_init (GpmManager *manager)
 				 "hibernate", G_CALLBACK (gpm_manager_tray_icon_hibernate),
 				 manager, G_CONNECT_SWAPPED);
 
-	gpm_debug ("initialising info infrastructure");
+	egg_debug ("initialising info infrastructure");
 	manager->priv->info = gpm_info_new ();
 
 	/* add the new statistics DBUS interface */
@@ -1859,9 +1836,6 @@ gpm_manager_finalize (GObject *object)
 	if (manager->priv->button) {
 		g_object_unref (manager->priv->button);
 	}
-	if (manager->priv->cpufreq) {
-		g_object_unref (manager->priv->cpufreq);
-	}
 	if (manager->priv->backlight) {
 		g_object_unref (manager->priv->backlight);
 	}
